@@ -17,8 +17,8 @@ import unittest
 from asn1crypto import x509 as asn1_x509
 from asn1crypto import pem as asn1_pem
 
-import python_x509_pkcs11.csr as csr
-from python_x509_pkcs11.PKCS11Handle import PKCS11Session
+from python_x509_pkcs11 import csr
+from python_x509_pkcs11.pkcs11_handle import PKCS11Session
 
 class TestCsr(unittest.TestCase):
     """
